package Qt::Gui::QActionGroup;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QActionGroup
# file     : QtGui/qactiongroup.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QObject/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QActionGroup

=head1 PUBLIC METHODS

=over

=item   QActionGroup(QObject * parent)

=item   ~QActionGroup()

=item  QAction * addAction(QAction * a)

=item  QAction * addAction(const QString & text)

=item  QAction * addAction(const QIcon & icon, const QString & text)

=item  QAction * checkedAction()

=item  bool isEnabled()

=item  bool isExclusive()

=item  bool isVisible()

=item  void removeAction(QAction * a)

=item  void setDisabled(bool b)

=item  void setEnabled(bool arg0)

=item  void setExclusive(bool arg0)

=item  void setVisible(bool arg0)


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
